@@ -18,11 +18,17 @@ install() {
     popd
 }
 
+PKG=$(<package.json)
+PKG_LOCK=$(<package-lock.json)
+
 # Link local packages into node_modules.
 install runtime
 install transform
 install preset
 
+echo "$PKG" > package.json
+echo "$PKG_LOCK" > package-lock.json
+
 # We need to use the symlink paths rather than the real paths, so that the
 # regenerator-* packages appear to reside in node_modules.
 node test/run.js
