@@ -885,6 +885,14 @@ describe("for-in loop generator", function() {
       "c"
     ]);
   });
+
+  it("should work with primitives", function () {
+    function *gen() {
+      for (var key in "abc") yield key;
+    }
+
+    check(gen(), [0, 1, 2]);
+  })
 });
 
 describe("yield chain", function() {
@@ -1495,6 +1503,18 @@ describe("delegated yield", function() {
 
     check(gen(iterator), [], "1foo");
   });
+
+  it("should throw if the delegated iterable's iterator doesn't have .next", function() {
+    var it = function* () {
+      yield* {
+        [Symbol.iterator]: x => [],
+      };
+    }();
+
+    assert.throws(() => {
+      it.next();
+    }, TypeError);
+  });
 });
 
 (fullCompatibility
@@ -2838,4 +2858,22 @@ describe("expressions containing yield subexpressions", function() {
       done: true,
     });
   });
+
+  it("should work when yield is in a sparse array", function() {
+    function *gen() {
+      return [0, yield "foo", , 3];
+    }
+
+    var g = gen();
+
+    assert.deepEqual(g.next(), {
+      value: "foo",
+      done: false,
+    });
+
+    assert.deepEqual(g.next(1), {
+      value: [0, 1, , 3],
+      done: true,
+    });
+  });
 });
